# Foreword

The following files are part of the Redfish development effort:

* DSP0218 - Platform Level Data Model (PLDM) for Redfish Device Enablement Specification - This document specifies the Binary-Encoded JSON (BEJ) and dictionary-based mapping of Redfish schemas and properties into PLDM messages.
* DSP0266 - Redfish Specification - This file is the main Redfish Specification.
* DSP0270 - Redfish Host Interface Specification - This document specifies the "in-band" or "OS-based" Redfish host interface.
* DSP0272 - Redfish Interoperability Profile Specification - This file specifies the structure and JSON document used to define and publish an interoperability profile used to check an implementation's conformance to a defined minimum set of functionality.
* DSP2044 - Redfish White Paper - This is intended to be a non-normative document helping those new to Redfish understand how to interact with the Redfish service and understand common functions and tasks.
* DSP2043 - Redfish Mockup - This is a mockup that can be used as sample output from GETs from a Redfish service.  Informative in nature, it was used to develop the schema.  A person can set up an NGINX or similar server and configure it to output JSON format and then use this directory for demonstration purposes.
* DSP8010 - Redfish Schema - This contains the Redfish schema definitions.  These files are normative in nature and are normatively referenced by the Redfish Specification.  There are three schema formats - CSDL (OData Common Schema Definition Language format, which is in XML), JSON Schema, and OpenAPI schema.  These schema definitions should be functionally equivalent, thus specifying the schema in two different languages.
* DSP8011 - Redfish Standard Registries - This contains the Redfish registry definitions.  This bundle of Redfish registries includes message registries used for Redfish-defined messages, including events, and privilege maps.
* DSP8013 - Redfish Interoperability Profiles - A bundle of published Redfish interoperability profile documents as well as supporting schema and sample documents used for creating profiles.

# Redfish Registry change log

| Registry File              | Version | Date       | Description |
| :---                       | :---    | :---       | :---        |
| JobEvent                   | 1.0.0   | 2020-08-04 | Initial release.  Defines messages for jobs. |
| LogService                 | 1.0.0   | 2020-08-04 | Initial release.  Defines messages for log services. |
| Redfish Privilege Registry | 1.1.0   | 2020-08-04 | Added entries for all resources defined by Redfish. |
| Base                       | 1.8.2   | 2020-08-04 | Errata release.  Clarified the `GeneralError` message to direct clients to either the `Resolution` property or `@Message.ExtendedInfo`.  Added descriptions to arguments for all messages. |
| StorageDevice              | 1.0.0   | 2020-04-30 | Initial release.  Defines messages for storage devices. |
| Base                       | 1.8.1   | 2020-04-30 | Errata release.  Updated to MessageRegistry v1.4.0 schema. |
| Composition                | 1.0.1   | 2020-04-30 | Errata release.  Added descriptions to arguments and updated to MessageRegistry v1.4.0 schema. |
| NetworkDevice              | 1.0.1   | 2020-04-30 | Errata release.  Added descriptions to arguments and updated to MessageRegistry v1.4.0 schema. |
| ResourceEvent              | 1.0.3   | 2020-04-30 | Errata release.  Added descriptions to arguments and updated to MessageRegistry v1.4.0 schema. |
| TaskEvent                  | 1.0.2   | 2020-04-30 | Errata release.  Added descriptions to arguments and updated to MessageRegistry v1.4.0 schema. |
| Base                       | 1.8.0   | 2020-03-27 | Added `MaximumErrorsExceeded`, `PreconditionFailed`, `PreconditionRequired`, `OperationFailed`, and `OperationTimeout`  messages. |
| NetworkDevice              | 1.0.0   | 2020-03-27 | Initial release. |
| Base                       | 1.7.0   | 2019-12-06 | Added `PropertyValueIncorrect` and `ResourceCreationConflict` messages. |
| Base                       | 1.6.1   | 2019-10-11 | Errata release.  Fixed typo in the resolution for the `NoValidSession` message. |
| Redfish Privilege Registry | 1.0.4   | 2019-10-11 | Errata release.  Corrected privileges for the `AccountService` and `Session` resources to show that anyone can read the account collection in order to find their own account, add to the session collection, and delete their own session.  Added `NoAuth` to allowed privileges for the service root. |
| Base                       | 1.6.0   | 2019-08-08 | Added `QueryNotSupportedOnOperation`, `ResetRequired`, `PropertyValueConflict`, `ChassisPowerStateOnRequired`, and `ChassisPowerStateOffRequired` messages. |
| Composition                | 1.0.0   | 2019-08-08 | Initial release.  Defines messages to use for composition events. |
| ResourceEvent              | 1.0.2   | 2019-08-08 | Errata release.  Corrected and clarified the description and message strings for all messages.  Removed `CorrespondingMessage` property from all messages. |
| Base                       | 1.5.0   | 2019-04-03 | Added `SubscriptionTerminated` and `PasswordChangeRequired` messages. |
| ResourceEvent              | 1.0.1   | 2018-11-29 | Corrected `@odata.type` and `Id` property formats.  Corrected cases where `ParamTypes` was incorrectly using `value`. |
| TaskEvent                  | 1.0.1   | 2018-11-29 | Corrected `@odata.type` and `Id` property formats.  Corrected cases where `ParamTypes` was incorrectly using `value`.  Fixed spelling of the `TaskProgressChanged` event. |
| ResourceEvent              | 1.0.0   | 2018-08-10 | Initial release.  Defines messages to use for resource events. |
| TaskEvent                  | 1.0.0   | 2018-08-10 | Initial release.  Defines messages to use for task events. |
| Base                       | 1.4.0   | 2018-08-10 | Added `NoOperation` message. |
| Base                       | 1.3.1   | 2018-08-10 | Errata release.  Clarified description and message text for `GeneralError`.  Implementations are expected to provide specific `Resolution` for this message. |
| Redfish Privilege Registry | 1.0.3   | 2018-08-10 | Errata release.  Corrected `ConfigureComponents` plurality privilege throughout.  Corrected JSON object structure throughout. |
| Base                       | 1.3.0   | 2018-04-05 | Added `PropertyValueOutOfRange` and `SessionTerminated` messages. |
| Base                       | 1.2.0   | 2017-08-18 | Added `ResourceNotFound`, `ResourceExhaustion`, `StringValueTooLong` and `EmptyJSON` messages.  Clarified description for `PropertyValueFormatError`.  Corrected parameters for `ResourceAlreadyExists`. |
| Redfish Privilege Registry | 1.0.2   | 2017-08-18 | Errata release.  Corrected `ConfigureUsers` plurality privilege throughout. |
| Base                       | 1.1.0   | 2017-05-19 | Added `ResourceInStandby` message. |
| Redfish Privilege Registry | 1.0.1   | 2017-05-19 | Initial release. |
| Base                       | 1.0.0   | 2015-11-25 | Initial release. |
